You are viewing a plain text version of this content. The canonical link for it is here.
Posted to fop-dev@xmlgraphics.apache.org by bu...@apache.org on 2003/05/14 22:18:41 UTC
DO NOT REPLY [Bug 19929] New: -
Changes to improve performance by about 10%
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
<http://nagoya.apache.org/bugzilla/show_bug.cgi?id=19929>.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND
INSERTED IN THE BUG DATABASE.
http://nagoya.apache.org/bugzilla/show_bug.cgi?id=19929
Changes to improve performance by about 10%
Summary: Changes to improve performance by about 10%
Product: Fop
Version: 0.20.5
Platform: PC
OS/Version: Windows NT/2K
Status: NEW
Severity: Enhancement
Priority: Other
Component: page-master/layout
AssignedTo: fop-dev@xml.apache.org
ReportedBy: sankara_tanguturi@yahoo.com
[PATCH]
Attached are some files in fop0.20.5 which I changed for improving performance.
In my project I noticed improvements of about 10%. Basically, I used
JProbe to identify excessive calls in FOP code and found that several
expensive calls (especially to PropertyListManager) could be eliminated by
storing
some of the results in the caller itself for later use.
The following is the list of files included in this zip file.
Thanks,
Sankara Tanguturi
sankara_tanguturi@yahoo.com
> org.apache.fop.fo.PropertyListBuilder.java
Eliminates unnecessary calls to findMaker function by storing it as a member
variable.
findMaker is expensive and is called from several member functions in
PropertyListBuilder.
By storing it the first time it is called and reusing when space, element,
attribute fields
match, the total calls are cut down.
> org.apache.fop.fo.flow.AbstractTableBody.java
Eliminated duplicate calls to getBorderAndPadding,
getBackkgroundProps,
getHyphenationProps, getMarginProps in layout by storing old values.
> org.apache.fop.fo.flow.Block.java
Eliminated duplicate calls to getBorderAndPadding,
getBackkgroundProps,
getHyphenationProps, getMarginProps in layout by storing old values.
> org.apache.fop.fo.flow.Table.java
Eliminated duplicate calls to getBorderAndPadding,
getBackkgroundProps,
getHyphenationProps, getMarginProps in layout by storing old values.
> org.apache.fop.fo.flow.TableCell.java
Made BorderAndPadding returned by propMgr.getBorderAndPadding() in doSetup as a
member variable
so that the call could be avoided in layout.
---------------------------------------------------------------------
To unsubscribe, e-mail: fop-dev-unsubscribe@xml.apache.org
For additional commands, email: fop-dev-help@xml.apache.org